/****************************************************************************
** Meta object code from reading C++ file 'IfdServiceContext.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../AusweisApp-2.5.5/src/workflows/ifd/context/IfdServiceContext.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'IfdServiceContext.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10governikus17IfdServiceContextE_t {};
} // unnamed namespace

template <> constexpr inline auto governikus::IfdServiceContext::qt_create_metaobjectdata<qt_meta_tag_ZN10governikus17IfdServiceContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "governikus::IfdServiceContext",
        "fireCardConnected",
        "",
        "QSharedPointer<CardConnection>",
        "pConnection",
        "fireDisplayTextChanged",
        "fireCardDisconnected",
        "fireUserError",
        "StatusCode",
        "pStatusCode",
        "fireEstablishPaceChannelUpdated",
        "fireIsRunningChanged",
        "fireAccessRightManagerCreated",
        "QSharedPointer<AccessRightManager>",
        "pAccessRightManager",
        "onMessageHandlerAdded",
        "QSharedPointer<ServerMessageHandler>",
        "pHandler",
        "reset"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fireCardConnected'
        QtMocHelpers::SignalData<void(const QSharedPointer<CardConnection> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fireDisplayTextChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fireCardDisconnected'
        QtMocHelpers::SignalData<void(const QSharedPointer<CardConnection> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fireUserError'
        QtMocHelpers::SignalData<void(StatusCode)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'fireEstablishPaceChannelUpdated'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fireIsRunningChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fireAccessRightManagerCreated'
        QtMocHelpers::SignalData<void(QSharedPointer<AccessRightManager>)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'onMessageHandlerAdded'
        QtMocHelpers::SlotData<void(QSharedPointer<ServerMessageHandler>) const>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Method 'reset'
        QtMocHelpers::MethodData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IfdServiceContext, qt_meta_tag_ZN10governikus17IfdServiceContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject governikus::IfdServiceContext::staticMetaObject = { {
    QMetaObject::SuperData::link<WorkflowContext::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus17IfdServiceContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus17IfdServiceContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10governikus17IfdServiceContextE_t>.metaTypes,
    nullptr
} };

void governikus::IfdServiceContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IfdServiceContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fireCardConnected((*reinterpret_cast<std::add_pointer_t<QSharedPointer<CardConnection>>>(_a[1]))); break;
        case 1: _t->fireDisplayTextChanged(); break;
        case 2: _t->fireCardDisconnected((*reinterpret_cast<std::add_pointer_t<QSharedPointer<CardConnection>>>(_a[1]))); break;
        case 3: _t->fireUserError((*reinterpret_cast<std::add_pointer_t<StatusCode>>(_a[1]))); break;
        case 4: _t->fireEstablishPaceChannelUpdated(); break;
        case 5: _t->fireIsRunningChanged(); break;
        case 6: _t->fireAccessRightManagerCreated((*reinterpret_cast<std::add_pointer_t<QSharedPointer<AccessRightManager>>>(_a[1]))); break;
        case 7: _t->onMessageHandlerAdded((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ServerMessageHandler>>>(_a[1]))); break;
        case 8: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<CardConnection> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<CardConnection> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<AccessRightManager> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ServerMessageHandler> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)(const QSharedPointer<CardConnection> & )>(_a, &IfdServiceContext::fireCardConnected, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)()>(_a, &IfdServiceContext::fireDisplayTextChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)(const QSharedPointer<CardConnection> & )>(_a, &IfdServiceContext::fireCardDisconnected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)(StatusCode )>(_a, &IfdServiceContext::fireUserError, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)()>(_a, &IfdServiceContext::fireEstablishPaceChannelUpdated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)()>(_a, &IfdServiceContext::fireIsRunningChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IfdServiceContext::*)(QSharedPointer<AccessRightManager> )>(_a, &IfdServiceContext::fireAccessRightManagerCreated, 6))
            return;
    }
}

const QMetaObject *governikus::IfdServiceContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *governikus::IfdServiceContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus17IfdServiceContextE_t>.strings))
        return static_cast<void*>(this);
    return WorkflowContext::qt_metacast(_clname);
}

int governikus::IfdServiceContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WorkflowContext::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void governikus::IfdServiceContext::fireCardConnected(const QSharedPointer<CardConnection> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void governikus::IfdServiceContext::fireDisplayTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void governikus::IfdServiceContext::fireCardDisconnected(const QSharedPointer<CardConnection> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void governikus::IfdServiceContext::fireUserError(StatusCode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void governikus::IfdServiceContext::fireEstablishPaceChannelUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void governikus::IfdServiceContext::fireIsRunningChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void governikus::IfdServiceContext::fireAccessRightManagerCreated(QSharedPointer<AccessRightManager> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
