/****************************************************************************
** Meta object code from reading C++ file 'NativeTextInput.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../../AusweisApp-2.5.5/src/ui/qml/modules/Native/NativeTextInput.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'NativeTextInput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15NativeTextInputE_t {};
} // unnamed namespace

template <> constexpr inline auto NativeTextInput::qt_create_metaobjectdata<qt_meta_tag_ZN15NativeTextInputE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NativeTextInput",
        "QML.Element",
        "auto",
        "accepted",
        "",
        "fontChanged",
        "textChanged",
        "textEdited",
        "textColorChanged",
        "backgroundColorChanged",
        "borderColorChanged",
        "borderRadiusChanged",
        "borderWidthChanged",
        "nativeWindowChanged",
        "maximumLengthChanged",
        "onParentChanged",
        "updateEffectiveOpacity",
        "font",
        "QFont",
        "textColor",
        "QColor",
        "backgroundColor",
        "borderColor",
        "borderWidth",
        "borderRadius",
        "maximumLength",
        "text",
        "nativeWindow",
        "QWindow*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accepted'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textEdited'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textColorChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderColorChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderRadiusChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'borderWidthChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nativeWindowChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumLengthChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onParentChanged'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateEffectiveOpacity'
        QtMocHelpers::SlotData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'font'
        QtMocHelpers::PropertyData<QFont>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(21, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'borderColor'
        QtMocHelpers::PropertyData<QColor>(22, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'borderWidth'
        QtMocHelpers::PropertyData<qreal>(23, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'borderRadius'
        QtMocHelpers::PropertyData<qreal>(24, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'maximumLength'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'text'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'nativeWindow'
        QtMocHelpers::PropertyData<QWindow*>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NativeTextInput, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject NativeTextInput::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15NativeTextInputE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15NativeTextInputE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15NativeTextInputE_t>.metaTypes,
    nullptr
} };

void NativeTextInput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NativeTextInput *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accepted(); break;
        case 1: _t->fontChanged(); break;
        case 2: _t->textChanged(); break;
        case 3: _t->textEdited(); break;
        case 4: _t->textColorChanged(); break;
        case 5: _t->backgroundColorChanged(); break;
        case 6: _t->borderColorChanged(); break;
        case 7: _t->borderRadiusChanged(); break;
        case 8: _t->borderWidthChanged(); break;
        case 9: _t->nativeWindowChanged(); break;
        case 10: _t->maximumLengthChanged(); break;
        case 11: _t->onParentChanged(); break;
        case 12: _t->updateEffectiveOpacity(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::accepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::fontChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::textChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::textEdited, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::textColorChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::backgroundColorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::borderColorChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::borderRadiusChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::borderWidthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::nativeWindowChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (NativeTextInput::*)()>(_a, &NativeTextInput::maximumLengthChanged, 10))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QFont*>(_v) = _t->font(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->textColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->borderColor(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->borderWidth(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->borderRadius(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->maximumLength(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 8: *reinterpret_cast<QWindow**>(_v) = _t->nativeWindow(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFont(*reinterpret_cast<QFont*>(_v)); break;
        case 1: _t->setTextColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 4: _t->setBorderWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setBorderRadius(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setMaximumLength(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setText(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *NativeTextInput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NativeTextInput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15NativeTextInputE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int NativeTextInput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void NativeTextInput::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NativeTextInput::fontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void NativeTextInput::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void NativeTextInput::textEdited()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void NativeTextInput::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void NativeTextInput::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void NativeTextInput::borderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void NativeTextInput::borderRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void NativeTextInput::borderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void NativeTextInput::nativeWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void NativeTextInput::maximumLengthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
