/****************************************************************************
** Meta object code from reading C++ file 'ChatModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../AusweisApp-2.5.5/src/ui/qml/ChatModel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ChatModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10governikus9ChatModelE_t {};
} // unnamed namespace

template <> constexpr inline auto governikus::ChatModel::qt_create_metaobjectdata<qt_meta_tag_ZN10governikus9ChatModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "governikus::ChatModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "onAuthenticationDataChanged",
        "",
        "QSharedPointer<AccessRightManager>",
        "pAccessRightManager",
        "transferAccessRights",
        "getFilterOptionalModel",
        "QSortFilterProxyModel*",
        "getFilterRequiredModel",
        "getFilterWriteModel",
        "optional",
        "required",
        "write"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onAuthenticationDataChanged'
        QtMocHelpers::SlotData<void(QSharedPointer<AccessRightManager>)>(5, 6, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'transferAccessRights'
        QtMocHelpers::MethodData<void() const>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'getFilterOptionalModel'
        QtMocHelpers::MethodData<QSortFilterProxyModel *()>(10, 6, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'getFilterRequiredModel'
        QtMocHelpers::MethodData<QSortFilterProxyModel *()>(12, 6, QMC::AccessPublic, 0x80000000 | 11),
        // Method 'getFilterWriteModel'
        QtMocHelpers::MethodData<QSortFilterProxyModel *()>(13, 6, QMC::AccessPublic, 0x80000000 | 11),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'optional'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(14, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'required'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(15, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'write'
        QtMocHelpers::PropertyData<QSortFilterProxyModel*>(16, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ChatModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject governikus::ChatModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus9ChatModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus9ChatModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10governikus9ChatModelE_t>.metaTypes,
    nullptr
} };

void governikus::ChatModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ChatModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onAuthenticationDataChanged((*reinterpret_cast<std::add_pointer_t<QSharedPointer<AccessRightManager>>>(_a[1]))); break;
        case 1: _t->transferAccessRights(); break;
        case 2: { QSortFilterProxyModel* _r = _t->getFilterOptionalModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        case 3: { QSortFilterProxyModel* _r = _t->getFilterRequiredModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        case 4: { QSortFilterProxyModel* _r = _t->getFilterWriteModel();
            if (_a[0]) *reinterpret_cast<QSortFilterProxyModel**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<AccessRightManager> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
        case 1:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QSortFilterProxyModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->getFilterOptionalModel(); break;
        case 1: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->getFilterRequiredModel(); break;
        case 2: *reinterpret_cast<QSortFilterProxyModel**>(_v) = _t->getFilterWriteModel(); break;
        default: break;
        }
    }
}

const QMetaObject *governikus::ChatModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *governikus::ChatModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus9ChatModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "SingletonCreator<ChatModel>"))
        return static_cast< SingletonCreator<ChatModel>*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int governikus::ChatModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
