/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0xac,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x17,0x5,0x15,0xd,0x0,0x26,0xd1,0x34,0x1d,0x50,0x6f,0x1b,
  0x37,0x53,0x46,0x4a,0x92,0xbb,0x11,0xb4,0x96,0xac,0x62,0xf1,0xb0,0xa2,0xe0,0x9c,
  0xa7,0x1d,0x2e,0x3c,0xbb,0xa3,0xa,0x1b,0xc1,0x4,0x2b,0x0,0x2e,0x0,0x2c,0x0,
  0xad,0x78,0xa5,0xd8,0x1e,0x26,0xf2,0x2a,0x16,0xcd,0x39,0x1b,0x79,0x8f,0xe0,0xab,
  0x93,0x47,0xc2,0x7a,0x95,0x60,0x3e,0xe3,0x6d,0xca,0xb9,0xf7,0xd3,0x2d,0x13,0x0,
  0x1e,0xd9,0x32,0xd4,0x4b,0x23,0x96,0xb6,0x8,0xb5,0xb,0x99,0xdf,0x96,0xd1,0x61,
  0x12,0x8c,0x9d,0xe0,0x2c,0xa8,0x15,0x0,0x8,0xa0,0x6c,0x85,0x6a,0x9a,0xa6,0x79,
  0x4b,0x33,0x58,0x50,0x23,0x85,0x4f,0x79,0x73,0x16,0x40,0x47,0xbc,0xfa,0x32,0xdf,
  0x98,0xb8,0x64,0xf7,0x6c,0xcf,0x6a,0xf9,0x2,0x9f,0x2f,0xf1,0x32,0xef,0x6b,0xa9,
  0x15,0x95,0x5f,0x89,0xfe,0x3e,0x1e,0x65,0xee,0x42,0x3e,0x9e,0x8,0xf6,0xf4,0xca,
  0x90,0x38,0x2b,0x10,0xcc,0xc2,0xb7,0xe8,0xfa,0xed,0xd4,0xc1,0xe2,0xd4,0xcc,0x38,
  0xb2,0x8d,0x49,0x19,0x1,0x4a,0xb1,0x67,0xa3,0xf3,0xce,0x72,0x88,0xf5,0x29,0xd4,
  0x93,0x7b,0x36,0xc,0xab,0x25,0x43,0x7d,0xde,0xa9,0x5b,0xc4,0x60,0xab,0x83,0xe2,
  0x11,0xd8,0x87,0xdf,0x94,0x3c,0xec,0xe7,0x9c,0x10,0xd2,0x9a,0xe2,0x32,0x31,0x65,
  0xa8,0x61,0x12,0x92,0x22,0x1a,0xa5,0x30,0xec,0x1d,0x40,0x44,0x20,0x12,0x1b,0x75,
  0x52,0x58,0x2c,0x4b,0x10,0xd1,0x8,0x46,0xc0,0x81,0x6,0xc9,0xa8,0x24,0xb5,0x3f,
  0x6b,0xd0,0x93,0x5e,0x78,0x94,0x1f,0x3f,0xaa,0xaa,0xed,0x27,0xa5,0x78,0x72,0x26,
  0xd1,0x1b,0x27,0xbf,0x48,0xd,0x59,0xbf,0xe4,0xe6,0x76,0xa4,0x7f,0xbf,0x97,0x74,
  0xc3,0x45,0xec,0xb6,0xf,0x9b,0x68,0x3b,0xb0,0xff,0xdc,0x15,0xad,0x30,0x36,0xbd,
  0x26,0x6,0x86,0x27,0x28,0xcb,0x5e,0xc8,0x84,0x99,0x69,0x64,0x21,0xf4,0xd0,0xf9,
  0x7b,0xde,0x25,0xf3,0xe0,0xab,0x43,0xca,0x7e,0xb8,0xde,0xee,0x61,0x74,0xa4,0xe9,
  0x45,0x8d,0xe6,0xe2,0x43,0x1c,0xa1,0xbd,0xc1,0x4d,0x3b,0x71,0xfa,0xe2,0xc9,0x8e,
  0x52,0xfb,0x63,0x3f,0x2f,0x98,0x9e,0xf0,0xcd,0xba,0xf8,0xd8,0xb5,0xc4,0xa8,0x2c,
  0x73,0x7d,0x22,0x40,0xcd,0xc,0xb0,0xf9,0x60,0x97,0x89,0xb6,0x5e,0xb,0xdc,0xab,
  0xbe,0xc4,0x13,0x1f,0x3d,0x40,0x8d,0x5f,0x94,0xd3,0x7e,0xfa,0xfc,0xcf,0x1e,0xd0,
  0x36,0xf9,0x22,0x4a,0xa5,0x5e,0x2c,0xba,0x75,0x12,0x77,0xf,0x37,0xc5,0x4b,0xbe,
  0xc6,0x86,0xe6,0x1,0xa5,0xd9,0x10,0x6a,0x7e,0xae,0x2,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Governikus
  0x0,0xa,
  0xc,0x9d,0x4f,0x43,
  0x0,0x47,
  0x0,0x6f,0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x6e,0x0,0x69,0x0,0x6b,0x0,0x75,0x0,0x73,
    // Animations
  0x0,0xa,
  0x3,0x84,0x10,0x53,
  0x0,0x41,
  0x0,0x6e,0x0,0x69,0x0,0x6d,0x0,0x61,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml/Governikus
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml/Governikus/Animations
  0x0,0x0,0x0,0x30,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml/Governikus/Animations/qmldir
  0x0,0x0,0x0,0x4a,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Governikus_Animations)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Governikus_Animations)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Governikus_Animations)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Governikus_Animations)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Governikus_Animations)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Governikus_Animations)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
