/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // qmldir
  0x0,0x0,0x1,0x7d,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x45,0x4,0x9d,0xb,0x0,0x76,0x90,0x33,0x1e,0x40,0x8f,0x1b,
  0xf,0x53,0x92,0x41,0x92,0xfd,0xa,0xfa,0xd3,0x93,0xa6,0x22,0x2f,0xb6,0xc,0x65,
  0x51,0xae,0xc1,0xe9,0xf0,0x9c,0x45,0xb1,0xaa,0xcb,0x1,0x2b,0x0,0x2a,0x0,0x2b,
  0x0,0xf,0x13,0x79,0x15,0xb,0x77,0x35,0x16,0xf2,0xde,0x3,0x57,0x2f,0x30,0x3e,
  0xed,0xb5,0xf2,0x7c,0x8b,0xd7,0xb1,0x8b,0x6e,0xa4,0xe2,0x9d,0x3c,0x7b,0xc2,0x8c,
  0x6,0x46,0x6b,0xd9,0xd5,0xd2,0x88,0xa6,0x2e,0x4e,0x7d,0x5,0x81,0xf6,0x9e,0xf,
  0xfb,0xe3,0xc3,0x1c,0xc7,0x71,0xbe,0xe2,0x8,0x9a,0x2b,0xa5,0xfe,0x18,0x74,0x57,
  0xa5,0x69,0x8a,0x57,0x5f,0xe6,0x21,0xc9,0x95,0xc,0x61,0x3a,0xa9,0xb9,0xe4,0xde,
  0x7f,0xcd,0x78,0xab,0xe8,0x2,0x9c,0xe0,0xde,0x4f,0xcf,0xa7,0xe,0x45,0x52,0x46,
  0xbe,0x9,0x4d,0x20,0xe4,0x25,0x65,0xad,0xf2,0xa3,0xcb,0x97,0xe2,0x2e,0x24,0x2c,
  0x49,0x29,0x4,0x7d,0x99,0x87,0xeb,0x94,0xea,0x50,0xd8,0x4d,0x21,0xb0,0x6,0x68,
  0x2,0x8c,0x59,0xd2,0xc6,0xc6,0x37,0x1a,0x9c,0x58,0x9f,0x4e,0xde,0xee,0x6,0x5e,
  0x48,0xdd,0xbb,0x5c,0xb2,0xeb,0xf3,0x4e,0xea,0x36,0xf,0xf9,0x59,0x50,0x98,0x3,
  0x6e,0x29,0x91,0x49,0x7f,0xbc,0xb5,0xa2,0xa6,0x2,0x4a,0xa0,0x81,0x96,0xa8,0x46,
  0xc6,0xd2,0x92,0xb4,0x9e,0x1,0x20,0x44,0xc8,0xb4,0xac,0x3,0xbe,0x42,0x4f,0x39,
  0x5,0x5,0x84,0x5c,0x65,0xf,0x12,0x1a,0x21,0x87,0x27,0x49,0x66,0x25,0x70,0x4f,
  0x82,0x85,0xb2,0x42,0x2b,0xea,0x9a,0x95,0xe0,0xb1,0x30,0x20,0x51,0x49,0x97,0x89,
  0x30,0xa0,0x38,0xb4,0x46,0xc,0x1b,0x88,0x2a,0xb7,0xa8,0x41,0x89,0x68,0xef,0x54,
  0xbc,0x88,0xbc,0xd4,0x4b,0xe0,0x22,0xb0,0x9a,0x50,0xf4,0x4a,0x1a,0xa7,0x99,0xb0,
  0xa7,0xda,0x2d,0xd2,0x2,0x96,0xbc,0x12,0x1c,0x3b,0xd8,0x2e,0x8e,0x92,0x16,0x1e,
  0x12,0x11,0xa3,0xa2,0x20,0xc2,0x98,0x86,0x41,0x9f,0x80,0x2c,0x1e,0x71,0x8d,0x6c,
  0x7f,0xca,0x2a,0xc3,0xb7,0xdd,0x46,0xf0,0x56,0x9f,0x8b,0xed,0xad,0x18,0xa,0xb7,
  0x6,0xe9,0x2e,0xe0,0x6,0x43,0x62,0x82,0x54,0xa,0xb1,0x99,0x61,0x20,0xf,0x8,
  0x6e,0x2,0x23,0x33,0x7,0x75,0x91,0x25,0x7b,0x21,0x54,0x1,
  
};

static const unsigned char qt_resource_name[] = {
  // qt
  0x0,0x2,
  0x0,0x0,0x7,0x84,
  0x0,0x71,
  0x0,0x74,
    // qml
  0x0,0x3,
  0x0,0x0,0x78,0x3c,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,
    // Governikus
  0x0,0xa,
  0xc,0x9d,0x4f,0x43,
  0x0,0x47,
  0x0,0x6f,0x0,0x76,0x0,0x65,0x0,0x72,0x0,0x6e,0x0,0x69,0x0,0x6b,0x0,0x75,0x0,0x73,
    // OnboardingView
  0x0,0xe,
  0x9,0x67,0xcb,0x7,
  0x0,0x4f,
  0x0,0x6e,0x0,0x62,0x0,0x6f,0x0,0x61,0x0,0x72,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x56,0x0,0x69,0x0,0x65,0x0,0x77,
    // qmldir
  0x0,0x6,
  0x7,0x84,0x2b,0x2,
  0x0,0x71,
  0x0,0x6d,0x0,0x6c,0x0,0x64,0x0,0x69,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml
  0x0,0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml/Governikus
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x4,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml/Governikus/OnboardingView
  0x0,0x0,0x0,0x30,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x5,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,
  // :/qt/qml/Governikus/OnboardingView/qmldir
  0x0,0x0,0x0,0x52,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0xa0,0x0,0xa2,0xe2,0xb0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Governikus_OnboardingView)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Governikus_OnboardingView)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Governikus_OnboardingView)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Governikus_OnboardingView)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_qmake_Governikus_OnboardingView)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_qmake_Governikus_OnboardingView)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
