/****************************************************************************
** Meta object code from reading C++ file 'PaosType.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../AusweisApp-2.5.5/src/workflows/base/paos/PaosType.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PaosType.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10governikus12EnumPaosTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto governikus::EnumPaosType::qt_create_metaobjectdata<qt_meta_tag_ZN10governikus12EnumPaosTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "governikus::EnumPaosType",
        "PaosType",
        "UNKNOWN",
        "STARTPAOS",
        "STARTPAOS_RESPONSE",
        "INITIALIZE_FRAMEWORK",
        "INITIALIZE_FRAMEWORK_RESPONSE",
        "DID_AUTHENTICATE_EAC1",
        "DID_AUTHENTICATE_RESPONSE_EAC1",
        "DID_AUTHENTICATE_EAC2",
        "DID_AUTHENTICATE_RESPONSE_EAC2",
        "DID_AUTHENTICATE_EAC_ADDITIONAL_INPUT_TYPE",
        "TRANSMIT",
        "TRANSMIT_RESPONSE"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PaosType'
        QtMocHelpers::EnumData<PaosType>(1, 1, QMC::EnumIsScoped).add({
            {    2, PaosType::UNKNOWN },
            {    3, PaosType::STARTPAOS },
            {    4, PaosType::STARTPAOS_RESPONSE },
            {    5, PaosType::INITIALIZE_FRAMEWORK },
            {    6, PaosType::INITIALIZE_FRAMEWORK_RESPONSE },
            {    7, PaosType::DID_AUTHENTICATE_EAC1 },
            {    8, PaosType::DID_AUTHENTICATE_RESPONSE_EAC1 },
            {    9, PaosType::DID_AUTHENTICATE_EAC2 },
            {   10, PaosType::DID_AUTHENTICATE_RESPONSE_EAC2 },
            {   11, PaosType::DID_AUTHENTICATE_EAC_ADDITIONAL_INPUT_TYPE },
            {   12, PaosType::TRANSMIT },
            {   13, PaosType::TRANSMIT_RESPONSE },
        }),
    };
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10governikus12EnumPaosTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}

static constexpr auto qt_staticMetaObjectContent_ZN10governikus12EnumPaosTypeE =
    governikus::EnumPaosType::qt_create_metaobjectdata<qt_meta_tag_ZN10governikus12EnumPaosTypeE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10governikus12EnumPaosTypeE =
    qt_staticMetaObjectContent_ZN10governikus12EnumPaosTypeE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10governikus12EnumPaosTypeE =
    qt_staticMetaObjectContent_ZN10governikus12EnumPaosTypeE.relocatingData;

Q_CONSTINIT const QMetaObject governikus::EnumPaosType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10governikus12EnumPaosTypeE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10governikus12EnumPaosTypeE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10governikus12EnumPaosTypeE.metaTypes,
    nullptr
} };

QT_WARNING_POP
