/****************************************************************************
** Meta object code from reading C++ file 'WebSocketServer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../AusweisApp-2.5.5/src/ifd/base/WebSocketServer.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'WebSocketServer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10governikus15WebSocketServerE_t {};
} // unnamed namespace

template <> constexpr inline auto governikus::WebSocketServer::qt_create_metaobjectdata<qt_meta_tag_ZN10governikus15WebSocketServerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "governikus::WebSocketServer",
        "fireNewConnection",
        "",
        "QSharedPointer<QWebSocket>",
        "pSocket",
        "fireConnectedChanged",
        "pConnected",
        "fireMessageHandlerAdded",
        "QSharedPointer<ServerMessageHandler>",
        "pHandler",
        "firePskChanged",
        "pPsk",
        "fireSocketError",
        "QAbstractSocket::SocketError",
        "pSocketError",
        "fireNameChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fireNewConnection'
        QtMocHelpers::SignalData<void(QSharedPointer<QWebSocket>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fireConnectedChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'fireMessageHandlerAdded'
        QtMocHelpers::SignalData<void(QSharedPointer<ServerMessageHandler>)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'firePskChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 11 },
        }}),
        // Signal 'fireSocketError'
        QtMocHelpers::SignalData<void(QAbstractSocket::SocketError)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'fireNameChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WebSocketServer, qt_meta_tag_ZN10governikus15WebSocketServerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject governikus::WebSocketServer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus15WebSocketServerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus15WebSocketServerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10governikus15WebSocketServerE_t>.metaTypes,
    nullptr
} };

void governikus::WebSocketServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WebSocketServer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fireNewConnection((*reinterpret_cast<std::add_pointer_t<QSharedPointer<QWebSocket>>>(_a[1]))); break;
        case 1: _t->fireConnectedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->fireMessageHandlerAdded((*reinterpret_cast<std::add_pointer_t<QSharedPointer<ServerMessageHandler>>>(_a[1]))); break;
        case 3: _t->firePskChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 4: _t->fireSocketError((*reinterpret_cast<std::add_pointer_t<QAbstractSocket::SocketError>>(_a[1]))); break;
        case 5: _t->fireNameChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<QWebSocket> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QSharedPointer<ServerMessageHandler> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstractSocket::SocketError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WebSocketServer::*)(QSharedPointer<QWebSocket> )>(_a, &WebSocketServer::fireNewConnection, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSocketServer::*)(bool )>(_a, &WebSocketServer::fireConnectedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSocketServer::*)(QSharedPointer<ServerMessageHandler> )>(_a, &WebSocketServer::fireMessageHandlerAdded, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSocketServer::*)(const QByteArray & )>(_a, &WebSocketServer::firePskChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSocketServer::*)(QAbstractSocket::SocketError )>(_a, &WebSocketServer::fireSocketError, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (WebSocketServer::*)()>(_a, &WebSocketServer::fireNameChanged, 5))
            return;
    }
}

const QMetaObject *governikus::WebSocketServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *governikus::WebSocketServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10governikus15WebSocketServerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int governikus::WebSocketServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void governikus::WebSocketServer::fireNewConnection(QSharedPointer<QWebSocket> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void governikus::WebSocketServer::fireConnectedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void governikus::WebSocketServer::fireMessageHandlerAdded(QSharedPointer<ServerMessageHandler> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void governikus::WebSocketServer::firePskChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void governikus::WebSocketServer::fireSocketError(QAbstractSocket::SocketError _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void governikus::WebSocketServer::fireNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
